/*******************************************************************
 
  kbd_hw.h - definitions of mmaped_8bit_bus_kbd hardware.
             The connected hardware is MA_KBD3 board connected
	     through emulated 8 bit paralel bus to EVB/Altera
	     DB4CGX15 PCI Express card through CON-DB4CGX15
	     adapter board. Original refernce design VID:PID
	     are used 1172:1f32 for mmaped_8bit_bus_kbd hardware
	     Quartus FPGA design.
 
  Copyright (C) 2011 by Pavel Pisa - originator 

  This code can be used and distributed under any license.
  THERE IS NO WARRANTY FOR THE SOFTWARE, TO THE EXTENT PERMITTED
  BY APPLICABLE LAW.

  The code is based on COLAMI code by Pavel Pisa and PiKRON company
  
  Components for embedded applications builded for
  laboratory and medical instruments firmware

 *******************************************************************/

#ifndef _KBD_HW_H_
#define _KBD_HW_H_

#include <stdint.h>

#ifndef STRINGIFY
#define STRINGIFY(x) STRINGIFY1(x)
#define STRINGIFY1(x) #x
#endif

/* MA_KBD3 register mapping on 8-bit emulated bus */
#define BUS_LCD_INST_o  0x0000 /* WR LCD instruction */
#define BUS_LCD_STAT_o  0x0001 /* RD LCD status */
#define BUS_LCD_WDATA_o 0x0002 /* WR LCD data to display or CG */
#define BUS_LCD_RDATA_o 0x0003 /* RD LCD RAM data */
#define BUS_LED_WR_o    0x0001 /* WR data to show on LED diodes */
#define BUS_KBD_WR_o    0x0003 /* WR data to keyboard scan register */
#define BUS_KBD_RD_o    0x0000 /* RD data returned from keyboard matrix */


#define EMUL_BUS_PCI_VENDOR_ID 0x1172
#define EMUL_BUS_PCI_DEVICE_ID 0x1f32

/* Registers mapping in PCIe mapping window as offset to BAR0 */
#define EMUL_BUS_CTRL_o     0x8040  /* +BAR0 WR-only bus control */
#define EMUL_BUS_DATA_OUT_o 0x8060  /* +BAR0 WR-only data to output on bus */
#define EMUL_BUS_DATA_IN_o  0x8080  /* +BAR0 RD-only read data on bus */

/* Masks for individual bits in EMUL_BUS_CTRL_o register */
#define EMUL_BUS_CTRL_A0_m  0x01
#define EMUL_BUS_CTRL_A1_m  0x02
#define EMUL_BUS_CTRL_RD_m  0x04
#define EMUL_BUS_CTRL_WR_m  0x08
#define EMUL_BUS_CTRL_CS0_m 0x10
#define EMUL_BUS_CTRL_PWR_m 0x80

#define EMUL_BUS_CTRL_INACTIVE_AND_PWR_ON_m \
  (EMUL_BUS_CTRL_RD_m|EMUL_BUS_CTRL_WR_m|EMUL_BUS_CTRL_CS0_m|\
   EMUL_BUS_CTRL_PWR_m)
#define EMUL_BUS_CTRL_ADDR_m \
  (EMUL_BUS_CTRL_A0_m|EMUL_BUS_CTRL_A1_m)

#endif /* _KBD_HW_H_ */
